@@ -22,5 +22,4 @@ pub const MESSAGE_EVENT_CODE: u16 = 0x000c;
 
 pub const BCM_ANIMATE_BRIGHTNESS_EVENT_CODE: u16 = 0x000d;
 
-pub const RELAY_SET_STATE_EVENT_CODE: u16 = 0x000e;
-pub const RELAY_FLIP_STATE_EVENT_CODE: u16 = 0x000f;
+pub const RELAY_SET_VALUE_EVENT_CODE: u16 = 0x000e;
